@@ -29,6 +29,7 @@ import pickle
 from datetime import date
 from datetime import timedelta
 from datetime import datetime
+import socket
 
 import soma.workflow.constants as constants
 from soma.workflow.client import FileTransfer
@@ -40,6 +41,8 @@ __docformat__ = "epytext en"
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+DB_VERSION = '1.0'
+
 strtime_format = '%Y-%m-%d %H:%M:%S'
 file_separator = ', '
 
@@ -221,7 +224,11 @@ def create_database(database_file):
                                            status             TEXT,
                                            last_status_update DATE NOT NULL,
                                            queue              TEXT) ''')
+
+  cursor.execute('''CREATE TABLE db_version (version TEXT NOT NULL)''')
   
+  cursor.execute('INSERT INTO db_version (version) VALUES (?)', [DB_VERSION])
+
   cursor.close()
   connection.commit()
   connection.close()
@@ -303,6 +310,31 @@ class WorkflowDatabaseServer( object ):
         print "Database creation " + database_file
         self.logger.info("Database creation " + database_file)
         create_database(database_file)
+      else:
+        connection = self._connect()
+        cursor = connection.cursor()
+        version = None
+        try:
+          for row in cursor.execute("SELECT * FROM db_version"):
+            version = row[0]
+        except Exception, e:
+          pass
+
+        try:
+          if version == None:
+            count = cursor.execute("SELECT count(*) FROM workflows WHERE "
+                                  "queue=?", ["default queue"]).next()[0]
+          elif unicode(version) != unicode(DB_VERSION):
+            raise Exception('Wrong db version')
+        except Exception, e:
+          cursor.close()
+          connection.close()
+          raise DatabaseError("Your database file might not be compatible "
+                              "with the current version of Soma-workflow.\n\n"
+                              "To solve the problem: \n  1. Log on the host"
+                              " " + repr(socket.gethostname()) + " (if it is not the current machine). \n  2. Delete"
+                              " the file " + str(database_file)+" \n"
+                              "  3. Clear the content of the directory: " + repr(tmp_file_dir_path))
       
       
       
@@ -868,6 +900,9 @@ class WorkflowDatabaseServer( object ):
     with self._lock:
       connection = self._connect()
       cursor = connection.cursor()
+      name = None
+      if engine_workflow.name != None:
+        name = engine_workflow.name.decode('utf8')
       try:
         cursor.execute('''INSERT INTO workflows 
                          (user_id,
@@ -881,7 +916,7 @@ class WorkflowDatabaseServer( object ):
                          (user_id,
                           None, 
                           engine_workflow.expiration_date,
-                          engine_workflow.name,
+                          name,
                           constants.WORKFLOW_NOT_STARTED,
                           datetime.now(),
                           engine_workflow.queue))
@@ -1007,9 +1042,9 @@ class WorkflowDatabaseServer( object ):
         raise DatabaseError('%s: %s \n' %(type(e), e))
       cursor.close()
       connection.close()
-      
-    pickled_workflow = self._string_conversion(pickled_workflow)
+    
     if pickled_workflow:
+      pickled_workflow = pickled_workflow.encode('utf-8')
       workflow = pickle.loads(pickled_workflow)
     else:
       workflow = None
@@ -1412,8 +1447,8 @@ class WorkflowDatabaseServer( object ):
       cursor.close()
       connection.close()
       
-    pickled_job = self._string_conversion(pickled_job)
     if pickled_job:
+      pickled_job = pickled_job.encode('utf-8')
       job = pickle.loads(pickled_job)
     else:
       job = None
@@ -1850,6 +1885,7 @@ class WorkflowDatabaseServer( object ):
         connection.close()
 
   def _string_conversion(self, string):
+    #return string
     if string: 
       return string.encode('utf-8')
     else: 
