@@ -23,10 +23,11 @@ from soma.workflow.configuration import LocalSchedulerCfg
 
 try:
   from soma.workflow.somadrmaajobssip import DrmaaJobs, DrmaaError
+  DRMAA_READY = True
 except ImportError:
   class DrmaaError(Exception): pass 
   class DrmaaJobs(object): pass
-
+  DRMAA_READY = False
 
 class Scheduler(object):
   '''
@@ -112,10 +113,14 @@ class Drmaa(Scheduler):
 
     self.logger = self.logger = logging.getLogger('ljp.drmaajs')
 
+    if not DRMAA_READY:
+      raise DRMError("ImportError, could not load the sip binding module for Drmaa: "
+                     "soma.workflow.somadrmaajobssip" ) 
     self._drmaa = DrmaaJobs()
     try:
       self._drmaa.initSession()
     except DrmaaError, e:
+      self.logger.critical("Could not create the DRMAA session: %s" %e )
       raise DRMError("Could not create the DRMAA session: %s" %e )
 
     self._drmaa_implementation = drmaa_implementation
@@ -142,6 +147,7 @@ class Drmaa(Scheduler):
                                 "[void]:" + os.path.join(self.tmp_file_path, "soma-workflow-empty-job-patch-torque.e"))
         self._drmaa.runJob(jobTemplateId)
       except DrmaaError, e:
+        self.logger.critical("%s" %e)
         raise DRMError("%s" %e)
       ################################
 
@@ -170,6 +176,7 @@ class Drmaa(Scheduler):
     try:
       self._drmaa.initSession()
     except DrmaaError, e:
+      self.logger.critical("Could not create the DRMAA session: %s" %e)
       raise DRMError("Could not create the DRMAA session: %s" %e )
 
   def job_submission(self, job):
@@ -247,7 +254,7 @@ class Drmaa(Scheduler):
       drmaaSubmittedJobId = self._drmaa.runJob(drmaaJobId)
       self._drmaa.deleteJobTemplate(drmaaJobId)
     except DrmaaError, e:
-      self.logger.debug("Error in job submission: %s" %(e))
+      self.logger.error("Error in job submission: %s" %(e))
       raise DRMError("Job submission error: %s" %(e))
 
     return drmaaSubmittedJobId
@@ -265,6 +272,7 @@ class Drmaa(Scheduler):
     try:
       status = self._drmaa.jobStatus(scheduler_job_id)
     except DrmaaError, e:
+      self.logger.error("%s" %(e))
       raise DRMError("%s" %(e))
     return status
 
@@ -331,6 +339,7 @@ class Drmaa(Scheduler):
     try:
       self._drmaa.terminate(scheduler_job_id)
     except DrmaaError, e:
+      self.logger.critical("%s" %e)
       raise DRMError("%s" %e)
   
 
